#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cmath>
using namespace std;

const int		MAX_N				= 16;
const int		MAX_LINE_LEN	= 1<<8;
const double	mypi				= acos(-1.0);
const double	eps				= 1e-9;
const double	final_eps		= 1e-5;
const double	INF				= 1e100;

struct point {
	double x, y;
	point () {}
	point (double _x, double _y) : x(_x), y(_y) {}

	point operator+(point &b) { return point(x+b.x,y+b.y); }
	point operator-(point &b) { return point(x-b.x,y-b.y); }
	point operator*(double k) { return point(x*k,y*k); }
	point operator/(double k) { return point(x/k,y/k); }
	point operator-() { return point(-x,-y); }
	double operator*(point &p) { return x*p.x + y*p.y; }
	point rot () { return point(-y,x); }
	double len2 () { return x*x + y*y; }
	double len () { return hypot(x,y); }
};

struct segm {
	point a, b;
	segm () {}
	segm (point _a, point _b) : a(_a), b(_b) {}

	point vec () { return point(b-a); }
};

int n;
point A, B;
segm M[MAX_N];					// mirrors
bool V[MAX_N];					// visited

void error (char *s)
{
	printf ("0\n%s\n", s);
	exit (0);
}

void input (char *file)
{
	FILE *fin = fopen(file, "r");
	
	int i;

	fscanf (fin, "%d", &n);
	fscanf (fin, "%lf%lf", &A.x, &A.y);
	fscanf (fin, "%lf%lf", &B.x, &B.y);

	for (i=0; i<n; i++) {
		fscanf (fin, "%lf%lf%lf%lf", &M[i].a.x, &M[i].a.y, &M[i].b.x, &M[i].b.y);
		if (M[i].vec().len() < 0.001) error("Too short segment in input!");
		if (fabs(M[i].a.x) > 10000+eps) error("Coordinates in input not in range!");
		if (fabs(M[i].a.y) > 10000+eps) error("Coordinates in input not in range!");
		if (fabs(M[i].b.x) > 10000+eps) error("Coordinates in input not in range!");
		if (fabs(M[i].b.y) > 10000+eps) error("Coordinates in input not in range!");
	}

	fclose (fin);
}

void check_output (char *output_file, char *solution_file)
{
	FILE *fout = fopen(output_file, "r");
	FILE *fsol = fopen(solution_file, "r");

	char *c;
	char ans_out[MAX_LINE_LEN];
	char ans_sol[MAX_LINE_LEN];
	double ang_out, ang_sol;
	bool is_correct=0;

	// from output_file
	fgets (ans_out, MAX_LINE_LEN, fout);
	if (strlen(ans_out) > MAX_LINE_LEN-10) error("Output overflow!");
	if (strcmp(ans_out,"YES\n")!=0 && strcmp(ans_out,"NO\n")!=0) error("Wrong YES/NO statement!");

	// from solution_file
	fgets (ans_sol, MAX_LINE_LEN, fsol);
	if (strcmp(ans_sol,ans_out)!=0) {
		if (strcmp(ans_sol,"YES\n")!=0) error ("Contestant says there is a solution but there is not!");
		else error ("Contestant says there is no solution but there is!");
	}

	// from output_file
	if (strcmp(ans_out,"YES\n")==0) {
		fgets (ans_out, MAX_LINE_LEN, fout);
		if (strlen(ans_out) > MAX_LINE_LEN-10) error("Output overflow!");
		for (c=ans_out; *c!='\0'; c++) if (*c==' ') error("Wrong angle format!");
		if (sscanf (ans_out, "%lf", &ang_out) != 1) error("Cannot read the angle!");

		while ( fgets (ans_sol, MAX_LINE_LEN, fsol) != NULL ) {
			sscanf (ans_sol, "%lf", &ang_sol);
			if ( fabs(ang_sol-ang_out) < 1e-6 + eps )
				is_correct = 1;
		}

		if (!is_correct) error("Wrong answer!");
	}

	if ( fgets(ans_out, MAX_LINE_LEN, fout) != NULL ) error("Too much output!");
	
	printf ("10\nOK\n");

	fclose (fout);
	fclose (fsol);
}

int main (int argc, char *argv[])
{
	if (argc<2) printf ("Use %s -input_file -output_file -solution_file\n", argv[0]);
	else {
		input (argv[1]);
		check_output (argv[2],argv[3]);
	}

	return 0;
}
