/*
PROB: mirrors
AUTHOR:  
COMPLEXITY: O(n!*n^2)
SOLUTION: 
	         ,
	,    0  1     
	  A,	          
	      B.    , 
	  ,     
	 (    
	  ).     ,
	           
	 A 	 B,    (
	       A).      ,
	  B     -    
	  .     ,  
	          
	      ,    
	           A.
*/

#include <cstdio>
#include <cmath>
#include <algorithm>
using namespace std;

const int		MAX_N	= 16;
const double	eps	= 1e-9;
const double	mypi	= acos(-1.0);

// /   
struct point {
	double x, y;
	point () {}
	point (double _x, double _y) : x(_x), y(_y) {}

    point operator+(point b) { return point(x+b.x,y+b.y); }
    point operator-(point b) { return point(x-b.x,y-b.y); } 
	point operator*(double k) { return point(x*k,y*k); }
	point rot () { return point(-y,x); }
	double len2 () { return x*x + y*y; }
};

//  ,   /
struct segm {
	point a, b;
	segm () {}
	segm (point _a, point _b) : a(_a), b(_b) {}
};

int n;						//  
point A, B;					//    
segm M[MAX_N];				//   
int order[MAX_N];			//        

void input ()
{
	int i;

	scanf ("%d", &n);
	scanf ("%lf%lf", &A.x, &A.y);
	scanf ("%lf%lf", &B.x, &B.y);

	for (i=0; i<n; i++)
		scanf ("%lf%lf%lf%lf", &M[i].a.x, &M[i].a.y, &M[i].b.x, &M[i].b.y);

	// -   
	random_shuffle (M, M+n);
}

//       
double orient (point &a, point &b, point &c)
{ return (b.x-a.x)*(c.y-b.y) - (c.x-b.x)*(b.y-a.y); }

//     p  ,    s
point orthoProj (point &p, segm &s)
{
	point v = s.b-s.a;
	return p - v.rot() * (2.0 * fabs(orient(p,s.a,s.b)) / v.len2());
}

//      (      p)
//  e>0.0 --          
//  e<0.0 --           
bool segm_intersect (segm g, segm h, point &p, double e)
{
	if ( orient(g.a,g.b,h.a)*orient(g.a,g.b,h.b) > e ) return 0;
	if ( orient(h.a,h.b,g.a)*orient(h.a,h.b,g.b) > e ) return 0;

	double S1 = orient(g.a,h.a,h.b);
	double S2 = orient(h.a,g.b,h.b);
	double coef = S1 / (S1+S2);

	p = g.a + (g.b-g.a)*coef;
	return 1;
}

//   g     ,         (   )
bool another_mirror_intersect (segm g)
{
	int i;
	static point p;

	for (i=0; i<n; i++)
		if ( segm_intersect(g,M[i],p,-eps) )
			if ( orient(M[i].a,M[i].b,g.a) > -eps )
				return 1;

	return 0;
}

//        B       
bool try_perm ()
{
	int i;
	static point proj[MAX_N];

	//   -    B
	// proj[i] -> i-     A       
	proj[0] = A;
	for (i=0; i<n; i++) {
		//     
		if ( orient(M[ order[i] ].a, M[ order[i] ].b, proj[i]) < -eps ) return 0;
		//      
		proj[i+1] = orthoProj(proj[i], M[ order[i] ]);
	}

	//  
	// proj[i] ->   (i-1)- ,     
	proj[n+1] = B;
	for (i=n; i>0; i--) {
		//        ( )
		if ( !segm_intersect ( segm(proj[i],proj[i+1]), M[ order[i-1] ], proj[i], eps ) ) return 0;
		//               
		if ( another_mirror_intersect( segm(proj[i],proj[i+1]) ) ) return 0;
	}

	//      n+1     / - -   A
	if ( another_mirror_intersect( segm(A,proj[1]) ) ) return 0;

	//     III-  IV- 
	double ang = 180.0/mypi * atan2(proj[1].y-A.y, proj[1].x-A.x);

	printf ("YES\n");
	printf ("%.6lf\n", ang + (ang<0.0 ? 360.0 : 0.0));

	return 1;
}

//         
void solve ()
{
	int i;

	for (i=0; i<n; i++) order[i] = i;

	do {
		if (try_perm ())
			return;
	} while ( next_permutation(order,order+n) );

	printf ("NO\n");
}

int main ()
{
	input ();
	solve ();

	return 0;
}
